#
# spec file for package systemtap-headers
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Note: this separate package systemtap-headers exists so that ring0
# packages can make use of the SDT headers without pulling in all
# build requirements of the normal systemtap package.  Normal use
# outside of BuildRequires in ring0 packages should use systemtap-sdt-devel
%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
Name:           systemtap-headers
Version:        5.0
Release:        150600.1.1
Summary:        SystemTap headers
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            http://sourceware.org/systemtap/
Source0:        https://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz
Source1:        https://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz.asc
Source2:        systemtap.keyring
Source3:        README-BEFORE-ADDING-PATCHES
Source4:        README-KEYRING
Source5:        stap-server.conf
Patch1:         systemtap-build-source-dir.patch

# sdt-devel provides the same header files as us, so we
# must conflict
Conflicts:      systemtap-sdt-devel

%description
SystemTap is an instrumentation system for systems running Linux.
This package contains only the headers for static system probes and
exists only to limit build cycles.  Normally you should install
systemtap-sdt-devel, which also contains these headers.

%prep
%setup -q -n systemtap-%{version}
%autopatch -p1

%build
# Our binutils always support '?' in the section characters on all
# architectures, no need for configure tests
sed -e 's/@support_section_question@/1/' < includes/sys/sdt-config.h.in > includes/sys/sdt-config.h

%install
mkdir -p %{buildroot}%{_includedir}/sys
cp -rp includes/sys/*.h %{buildroot}%{_includedir}/sys/

%files
%defattr(-,root,root)
%{_includedir}/sys/*.h

%changelog
* Fri Apr 26 2024 tonyj@suse.com
- Upgrade to version 5.0. See systemtap.spec for changelog
* Thu Jul 20 2023 tonyj@suse.com
- Upgrade to version 4.9. See systemtap.spec for changelog
  Delete patch (upstream): sys-sdt.h-fp-constraints-arm32.patch
  Delete patch (upstream): sys-sdt.h-fp-constraints-x86_64.patch
  Delete patch (upstream): sys-sdt.h-fp-constraints-aarch64-s390.patch
* Thu Apr 21 2022 tonyj@suse.com
- Resolve failed s390x glibc build (bsc#1198442)
    New patch: handle-user-supplied-sdt-probe-argument-template.patch
* Mon Feb 14 2022 tonyj@suse.com
- Resolve gcc compilation error reported against glib2 and libvirt
    New patch: sys-sdt.h-fp-constraints-arm32.patch
    New patch: sys-sdt.h-fp-constraints-x86_64.patch
    New patch: sys-sdt.h-fp-constraints-aarch64-s390.patch
* Thu Jan 27 2022 tonyj@suse.com
- Upgrade to version 4.6. See systemtap.spec for changelog
* Fri Dec  6 2019 tonyj@suse.com
- Upgrade to version 4.2. See systemtap.spec for changelog
* Wed Nov  6 2019 tonyj@suse.com
- Upgrade to version 4.1. See systemtap.spec for changelog
* Fri Feb 16 2018 matz@suse.com
- Add Conflicts with systemtap-sdt-devel, as that one again
  provides the headers as well.
* Thu Feb  8 2018 matz@suse.com
- Created new specfile systemtap-headers.spec, so bootstrap cycles
  packages can use them without blowing up the cycle.
  [fate#324969]
